@@ -28,7 +28,6 @@
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
-#include <libmate-desktop/mate-aboutdialog.h>
 
 #include <mate-panel-applet.h>
 #include <mate-panel-applet-gsettings.h>
@@ -49,10 +48,6 @@
 #define GK_COMMAND_OUTPUT  "Output"
 #define GK_COMMAND_ICON    "Icon"
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
-#endif
-
 typedef struct
 {
     MatePanelApplet   *applet;
@@ -108,9 +103,13 @@ command_about_callback (GtkAction *action, CommandApplet *command_applet)
 {
     const char* authors[] = { "Stefano Karapetsas <stefano@karapetsas.com>", NULL };
 
-    mate_show_about_dialog(NULL,
+    char copyright[] = \
+         "Copyright \xc2\xa9 2015-2016 MATE developers\n"
+         "Copyright \xc2\xa9 2013-2014 Stefano Karapetsas";
+
+    gtk_show_about_dialog(NULL,
                           "version", VERSION,
-                          "copyright", "Copyright © 2013-2014 Stefano Karapetsas",
+                          "copyright", copyright,
                           "authors", authors,
                           "comments", _("Shows the output of a command"),
                           "translator-credits", _("translator-credits"),
@@ -123,7 +122,7 @@ static void
 command_settings_callback (GtkAction *action, CommandApplet *command_applet)
 {
     GtkDialog *dialog;
-    GtkTable *table;
+    GtkGrid *grid;
     GtkWidget *widget;
     GtkWidget *command;
     GtkWidget *interval;
@@ -136,9 +135,9 @@ command_settings_callback (GtkAction *action, CommandApplet *command_applet)
                                                      GTK_STOCK_CLOSE,
                                                      GTK_RESPONSE_CLOSE,
                                                      NULL));
-    table = GTK_TABLE (gtk_table_new (4, 2, FALSE));
-    gtk_table_set_row_spacings (table, 12);
-    gtk_table_set_col_spacings (table, 12);
+    grid = GTK_GRID (gtk_grid_new ());
+    gtk_grid_set_row_spacing (grid, 12);
+    gtk_grid_set_column_spacing (grid, 12);
 
     gtk_window_set_default_size (GTK_WINDOW (dialog), 350, 150);
     gtk_container_set_border_width (GTK_CONTAINER (dialog), 10);
@@ -150,14 +149,10 @@ command_settings_callback (GtkAction *action, CommandApplet *command_applet)
 #else
     gtk_misc_set_alignment (GTK_MISC (widget), 1.0, 0.5);
 #endif
-    gtk_table_attach (table, widget, 1, 2, 0, 1,
-                      GTK_FILL, GTK_FILL,
-                      0, 0);
+    gtk_grid_attach (grid, widget, 1, 0, 1, 1);
 
     command = gtk_entry_new ();
-    gtk_table_attach (table, command, 2, 3, 0, 1,
-                      GTK_EXPAND | GTK_FILL | GTK_SHRINK, GTK_FILL,
-                      0, 0);
+    gtk_grid_attach (grid, command, 2, 0, 1, 1);
 
     widget = gtk_label_new (_("Interval (seconds):"));
 #if GTK_CHECK_VERSION (3, 16, 0)
@@ -166,14 +161,10 @@ command_settings_callback (GtkAction *action, CommandApplet *command_applet)
 #else
     gtk_misc_set_alignment (GTK_MISC (widget), 1.0, 0.5);
 #endif
-    gtk_table_attach (table, widget, 1, 2, 1, 2,
-                      GTK_FILL, GTK_FILL,
-                      0, 0);
+    gtk_grid_attach (grid, widget, 1, 1, 1, 1);
 
     interval = gtk_spin_button_new_with_range (1.0, 600.0, 1.0);
-    gtk_table_attach (table, interval, 2, 3, 1, 2,
-                      GTK_EXPAND | GTK_FILL | GTK_SHRINK, GTK_FILL,
-                      0, 0);
+    gtk_grid_attach (grid, interval, 2, 1, 1, 1);
 
     widget = gtk_label_new (_("Maximum width (chars):"));
 #if GTK_CHECK_VERSION (3, 16, 0)
@@ -182,21 +173,15 @@ command_settings_callback (GtkAction *action, CommandApplet *command_applet)
 #else
     gtk_misc_set_alignment (GTK_MISC (widget), 1.0, 0.5);
 #endif
-    gtk_table_attach (table, widget, 1, 2, 2, 3,
-                      GTK_FILL, GTK_FILL,
-                      0, 0);
+    gtk_grid_attach (grid, widget, 1, 2, 1, 1);
 
     width = gtk_spin_button_new_with_range(1.0, 100.0, 1.0);
-    gtk_table_attach (table, width, 2, 3, 2, 3,
-                      GTK_EXPAND | GTK_FILL | GTK_SHRINK, GTK_FILL,
-                      0, 0);
+    gtk_grid_attach (grid, width, 2, 2, 1, 1);
 
     showicon = gtk_check_button_new_with_label (_("Show icon"));
-    gtk_table_attach (table, showicon, 2, 3, 3, 4,
-                      GTK_EXPAND | GTK_FILL | GTK_SHRINK, GTK_FILL,
-                      0, 0);
+    gtk_grid_attach (grid, showicon, 2, 3, 1, 1);
 
-    gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (dialog)), GTK_WIDGET (table), TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (dialog)), GTK_WIDGET (grid), TRUE, TRUE, 0);
 
     g_signal_connect (dialog, "response", G_CALLBACK (gtk_widget_destroy), dialog);
 
@@ -263,6 +248,65 @@ settings_interval_changed (GSettings *settings, gchar *key, CommandApplet *comma
     command_execute (command_applet);
 }
 
+static void
+process_command_output (CommandApplet *command_applet, gchar *output)
+{
+    gtk_widget_set_tooltip_text (GTK_WIDGET (command_applet->label), command_applet->command);
+
+    if ((output == NULL) || (output[0] == 0))
+    {
+        gtk_label_set_text (command_applet->label, ERROR_OUTPUT);
+        return;
+    }
+
+    /* check if output is a custom GKeyFile */
+    if (g_str_has_prefix (output, "[Command]"))
+    {
+        GKeyFile *file = g_key_file_new ();
+        if (g_key_file_load_from_data (file, output, -1, G_KEY_FILE_NONE, NULL))
+        {
+            gchar *goutput = g_key_file_get_string (file, GK_COMMAND_GROUP, GK_COMMAND_OUTPUT, NULL);
+            gchar *icon = g_key_file_get_string (file, GK_COMMAND_GROUP, GK_COMMAND_ICON, NULL);
+
+            if (goutput)
+            {
+                gtk_label_set_use_markup (command_applet->label, TRUE);
+                gtk_label_set_markup (command_applet->label, goutput);
+            }
+
+            if (icon)
+                gtk_image_set_from_icon_name (command_applet->image, icon, 24);
+
+            g_free (goutput);
+            g_free (icon);
+        }
+        else
+            gtk_label_set_text (command_applet->label, ERROR_OUTPUT);
+
+        g_key_file_free (file);
+    }
+    else
+    {
+        /* check output length */
+        if (strlen(output) > command_applet->width)
+        {
+            GString *strip_output;
+            strip_output = g_string_new_len (output, command_applet->width);
+            g_free (output);
+            output = strip_output->str;
+            g_string_free (strip_output, FALSE);
+        }
+
+        /* remove last char if it is '\n' to avoid alignment problems */
+        if (g_str_has_suffix (output, "\n"))
+        {
+            output[strlen(output) - 1] = 0;
+        }
+
+        gtk_label_set_text (command_applet->label, output);
+    }
+}
+
 static gboolean
 command_execute (CommandApplet *command_applet)
 {
@@ -272,56 +316,7 @@ command_execute (CommandApplet *command_applet)
 
     if (g_spawn_command_line_sync (command_applet->command, &output, NULL, &ret, &error))
     {
-        gtk_widget_set_tooltip_text (GTK_WIDGET (command_applet->label), command_applet->command);
-
-        if ((output != NULL) && (output[0] != 0))
-        {
-            /* check if output is a custom GKeyFile */
-            if (g_str_has_prefix (output, "[Command]"))
-            {
-                GKeyFile *file = g_key_file_new ();
-                if (g_key_file_load_from_data (file, output, -1, G_KEY_FILE_NONE, NULL))
-                {
-                    gchar *goutput = g_key_file_get_string (file, GK_COMMAND_GROUP, GK_COMMAND_OUTPUT, NULL);
-                    gchar *icon = g_key_file_get_string (file, GK_COMMAND_GROUP, GK_COMMAND_ICON, NULL);
-
-                    if (goutput)
-                    {
-                        gtk_label_set_use_markup (command_applet->label, TRUE);
-                        gtk_label_set_markup (command_applet->label, goutput);
-                    }
-                    if (icon)
-                        gtk_image_set_from_icon_name (command_applet->image, icon, 24);
-
-                    g_free (goutput);
-                    g_free (icon);
-                }
-                else
-                    gtk_label_set_text (command_applet->label, ERROR_OUTPUT);
-                g_key_file_free (file);
-            }
-            else
-            {
-                /* check output length */
-                if (strlen(output) > command_applet->width)
-                {
-                    GString *strip_output;
-                    strip_output = g_string_new_len (output, command_applet->width);
-                    g_free (output);
-                    output = strip_output->str;
-                    g_string_free (strip_output, FALSE);
-                }
-                /* remove last char if it is '\n' to avoid aligment problems */
-                if (g_str_has_suffix (output, "\n"))
-                {
-                    output[strlen(output) - 1] = 0;
-                }
-
-                gtk_label_set_text (command_applet->label, output);
-            }
-        }
-        else
-            gtk_label_set_text (command_applet->label, ERROR_OUTPUT);
+        process_command_output (command_applet, output);
     }
     else
         gtk_label_set_text (command_applet->label, ERROR_OUTPUT);
@@ -355,7 +350,7 @@ command_applet_fill (MatePanelApplet* applet)
     command_applet->command = g_settings_get_string (command_applet->settings, COMMAND_KEY);
     command_applet->width = g_settings_get_int (command_applet->settings, WIDTH_KEY);
 
-    command_applet->box = GTK_BOX (gtk_hbox_new (FALSE, 0));
+    command_applet->box = GTK_BOX (gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0));
     command_applet->image = GTK_IMAGE (gtk_image_new_from_icon_name (APPLET_ICON, 24));
     command_applet->label = GTK_LABEL (gtk_label_new (ERROR_OUTPUT));
     command_applet->timeout_id = 0;
